<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace NCSU\Auth;

interface AuthServiceInterface
{
    /**
     * Attempts to authenticate a user and provides an authentication result.
     * @return AuthResult
     */
    public function authenticate();

    /**
     * Returns true if identity exists. False otherwise.
     * @return boolean
     */
    public function hasIdentity();

    /**
     * Retrieves the identity if it exists. Null otherwise.
     * @return mixed|null
     */
    public function getIdentity();

    /**
     * Clears the authenticated identity's session.
     * @return void
     */
    public function logout();

    /**
     * Returns true if the user is authenticated, false otherwise
     * @return bool
     */
    public function isAuthenticated();
} 