<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth\Storage;

/**
 * An in-memory non-persistent storage implementation.
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
class MemoryStorage implements StorageInterface
{
    /**
     * @var mixed Authentication data.
     */
    protected $data;

    /**
     * Determines if storage is empty.
     * @return boolean
     */
    public function isEmpty()
    {
        return empty($this->data);
    }

    /**
     * Reads contents of storage. Returns null if empty.
     * @return mixed|null
     */
    public function read()
    {
        return $this->data ?: null;
    }

    /**
     * Writes contents to storage.
     *
     * @param mixed $contents
     *
     * @return void
     */
    public function write($contents)
    {
        $this->data = $contents;
    }

    /**
     * Clears storage.
     * @return void
     */
    public function clear()
    {
        $this->data = null;
    }
}